#!/bin/bash

#*****************************************************************************#
#                               SauvegardeGeneralePC.sh                       #
#                              écrit par Rafael Venancio                      #
#                                 05 Juin 2010                                #
#*****************************************************************************#



# Versions
#==============================================================================
# 1.0 le  5/06/2010 Rafael Venancio
#
# 2.0 le 12/06/2010 
#  - ajout possibilité de multiples exclusions de sous-répertoires (une seule exclusion auparavant).
#  - factorisation de la liste des types de fichiers à exclures, permettant un réglages.
#  - prise en compte correcte de toutes les exclusions dans le calcul des occupations disques. 
#  - zone des réglages initiaux plus compréhensible
#  - simplification du code 
#
# 2.1 le 28/06/2010
# - Ajout date et heure du lancement du script, à l'affichage et dans le fichier de log.
# - En cas d'interruption, automatique ou manuelle, effacement du fichier temporaire 'exclusionRepertoireEtFichier'.
# - En cas d'interruption et si aucun archive n'a encore été crée, effacement du fichier local de log. 
# - Création des fichiers temporaires et d'archives dans un repertoire local caché '.temp'.
# - Ajout d'un test dans sous-programme 'SauvegardeGeneralePc_SousProgr1.sh' pour qu'il ne fonctionne qu'avec ce script.
# - Ajout vérification de la présence des requis au demarrage du script.
# - Change les permissions du script de sous-programme pour le rendre executable et vérifie ce changement. 
# - Amélioration affichage du calcul occupation disque de la sauvegarde.
# - Amélioration du code.
#
# 2.2 le ../../2010
# - Vérification du retour de la commande 'df'. Car suivant la version de Mandriva (ou du bureau ?) cette commande retourne la valeur numérique (Netbook MSI avec Mandriva 2009 spring XFCE et AMD 64 Athlon avec Mandriva 2010 KDE) ou bien de 2 lignes composées du titre de la colonne et de la valeur numérique (AMD 64 Athlon avec Mandriva 2010 Spring KDE). 


# Ce que fait le script
#==============================================================================
# - Réalise la sauvegarde des repertoires et partitions sélectionnés, d'un PC
#   vers un disque dure USB externe, entièrement automatiquement. Sauvegarde
#   totale, pas incrémentale.
# - Crée des archives (non compressés) en découpant celle-ci en fichiers de 2 Go
#   maximum chacun, avec l'application 'dar' http://dar.lunix.free.fr/ ,
#   http://fr.wikipedia.org/wiki/DAR (en français).
# - Vérifie l'installation des requis et la présence du script de sous-programme.	
# - Vérifie que l'espace libre sur le disque du PC permet la création locale des 
#   fichiers de 2 Go.
# - Affiche l'occupation disque correspondant à la sauvegarde totale.
# - Vérifie que le disque dure USB externe dispose de suffisemment d'espace libre
#   pour la sauvegarde totale. 
# - Crée un répertoire avec la date du jour, sur le disque USB, pour contenir la
#   sauvegarde. 
# - Calcul un checksum sha1, http://fr.wikipedia.org/wiki/SHA-1, pour chaque 
#   fichier d'archive.
# - Copie les fichiers archives et les checksum de fichiers sur le disque USB.
# - Vérifie le checksum des fichiers copiés sur le disque USB (non conrruption
#   lors de la copie).
# - supprime les fichiers d'archive du PC une fois réalisé la vérification.
# - Effectue toutes ces opérations sur chaque fichier d'archive de 2 Go, au fur 
#   et à mesure, puis efface celui-ci du PC avant de créer le suivant. Pour 
#   réduire l'espace disque nécessaire sur le PC lors du fonctionnent du script.
# - Crée un fichier des checksum de l'ensemble des fichiers d'une archive pour 
#   faciliter une vérification manuelle, si necessaire.
# - Crée un fichier de Log, équivalent à l'affichage sur la console, et copie 
#   celui-ci sur le disque USB.
# - Copie les fichiers du script sur le disque USB.

# Utilisation des sauvegardes
#==============================================================================
# - Desarchivage des sauvegardes globales ou d'un fichier individuel avec 
#   l'application 'DarGUI' pour Linux, http://sourceforge.net/projects/dargui/.
# - Il est possible d'utiliser 'dar' en ligne de commande mais je ne vois pas
#   l'interrêt. 

# Mode d'emploi au quotidien
#==============================================================================
# - Brancher le disque dure USB externe et vérifier qu'il est reconnut par l'OS.
# - Stopper les programmes en cours qui pourraient modifier les données à sauvegarder.
# - Ouvrir une console dans le répertoire du PC qui contient ce script.
# - Taper la commande 'sh SauvegardeGeneralePC.sh' et faire Entrée.
# - Suivre les indications à l'écran.
# - Pendant la sauvegarde, ne pas faire fonctionner des programmes qui pourraient
#   modifier les données à sauvegarder.

# Commentaires et remarques
#==============================================================================
# - Les fichiers iso (images de CD/DVD) ne sont pas archivées car je considère
#   que ces données sont toujours téléchargeables. Ces exclusions sont modifiables.
# - La durée de sauvegarde est plus influencée par la puissance du processeur que
#   le volume des données. Ceci en raison de la création des archives et des
#   calculs des cheksum sha1. 65 Go de sauvegarde prend 2h30 sur mon PC fixe 
#   AMD Athlon64 et environ 7h00 sur mon NetBook MSI.

# Installation et paramétrage à faire la 1ère fois.
#==============================================================================
# - Utiliser de préference un éditeur de fichier type Gedit ou Kate. La coloration
#   syntaxique de ces éditeurs facilitera la lecture du code.
# - Vérifier que les requis ci-dessous sont respectés.
# - Copier ce fichier et le sous-programme 'SauvegardeGeneralePc_SousProgr1.sh'
#   dans un répertoire du PC avec au moins 5 Go d'espace disque libre. 
# - Régler l'arborescence de destination vers le disque USB externe.
#   Voir '>>>>> REGLAGE INITIAL 1 <<<<<' dans le code ci-dessous.
#   Cette arboresence doit correspondre à celle existante jusqu'au repertoire 
#   de destination sur le disque USB. Elle n'est pas crée par le script. 
# - Régler les partitions et repertoires à sauvegarder/exclure dans la 
#   fonction 'Partitions et répertoires de sauvegarde'.
#   Voir '>>>>> REGLAGE INITIAL 2 <<<<<' dans le code ci-dessous.
# - Modifier éventuellement les types de fichiers qui seront systématiquement exclus.
#   Voir '>>>>> REGLAGE INITIAL 3 <<<<<' dans le code ci-dessous. 
# - Lancer le script jusqu'à la vérification de l'espaces disques disponibles 
#   et necessaires. Ceci permet de vérifier l'arborescence des répertoires à 
#   sauvegarder. 
# - Conseil : utiliser un logiciel de visualisation d'occupation disque du PC
#   sous forme graphique (exemple : xDiskUsage sous Linux) pour décider en tout 
#   état de cause ce qu'il faut sauvegarder.

# Requis
#==============================================================================
# - Logiciel 'dar'. Pour vérifier sa présence, taper en console : "dar --help"
# - Logiciel 'bc'. Programme à part, qui fournit un langage de calcul. Pour 
#   vérifier sa présence, taper en console : "bc --help"
# - 'sha1sum'. Il est souvent installé par defaut. Pour vérifier sa présence, 
#   taper en console : "sha1sum --help"
# - Le script de sous-programme 'SauvegardeGeneralePc_SousProgr1.sh', présent
#   dans le même repertoire de le script principal. 
#
# - 'DarGui' pour relire les archives en mode graphique, les extraires en totalité
#   ou un seul fichier. 

# Principe de l'arborescence des sauvegardes sur le disque dur USB
#==============================================================================
# Voici l'arborescence que j'utilise personnellement.
#
# SAUVEGARDE (nom du disque dur USB)
#     |
#      --- AmdAthlon64 (un de mes PC)
#     | 
#      --- Portable_1 (un de mes PC)
#     | 
#      --- PowerNet (un de mes PC)
#     | 
#      --- Netbook_MSI (le PC de ce script) <<<<< REGLAGE INITIAL 1
#            |
#             --- Sauvg_2010-05-01 (création automatique)
#            |
#             --- Sauvg_2010-05-15 (création automatique)
#            |
#             --- Sauvg_2010-06-01 (création automatique)
#                    |
#                     --- Mandriva (partition Linux) <<<<< REGLAGE INITIAL 2 - Partition PC
#                    |       |
#                    |        --- papa (mon /home) <<<<< REGLAGE INITIAL 2 - Répertoire PC
#                    |       |
#                    |        --- thunderbird (mes courriels) <<<<< REGLAGE INITIAL 2 - Répertoire PC
#                    |
#                     --- WindowsXP (partition Windows) <<<<< REGLAGE INITIAL 2 - Partition PC
#                    |       |
#                    |        --- Bureau (le bureau) <<<<< REGLAGE INITIAL 2 - Répertoire PC
#                    |       |
#                    |        --- MesDocuments (mes documents) <<<<< REGLAGE INITIAL 2 - Répertoire PC
#                    | 
#                     --- Disque (partition de partage Linux/Windows) <<<<< REGLAGE INITIAL 2 - Partition PC
#
# Pourquoi cette arborescence ?
# - j'ai plusieurs PC.
# - je sauvegarde tous mes PC sur un même disque dure USB externe.
# - je sauvegarde l'intégralité du PC (toutes les partitions) à chaque fois.
#
# Ceci me permet :
# - de facilement retrouver les sauvegardes par rapport aux dates.
# - de facilement effacer les plus anciennes sauvegarde (répertoire 'Sauvg_AAAA-MM-JJ')
#   pour ne conserver que les 3 dernières. 
# - si je souhaite placer une sauvegarde sur un site en ligne, je prend une 
#   sauvegarde à date.

# Mise au point et tests avec une clef USB au lieu d'un disque USB
#==============================================================================
# - Régler l'arborescence de destination vers le disque USB externe dans 
#   '>>>>> REGLAGE INITIAL 1 <<<<<'.
# - Régler la fonction'Partitions et répertoires de sauvegarde pour test sur une
#   clef USB' en fonction de la capacité de la clef USB. 
#   Après '>>>>> REGLAGE INITIAL 2 <<<<<' 
# - Taper la commande 'sh SauvegardeGeneralePC.sh test'. Le mot 'test' est ajouté. 

# Les raisons de mes choix
#==============================================================================
# - Création d'archives au lieu de sauvegardes directes des fichiers : 
#   Pas de soucis de copie sur le disque USB même avec des arborescences très 
#   complexes des partitions et répertoires.
#   La création d'archive de 2 Go réduit très fortement le nombre de fichier à 
#   copier.
#   Permet de cacluler facilement des checksums car peu de fichiers.
# - Calcul de checksum 'sha1' : 
#   Permet de vérifier que les archives ne sont pas corrompues au fil du temps,
#   avec un stockage de longue durée ou lors des copies d'un support à l'autre
#   (disque dure, disque USB, etc..).
# - Pourquoi ne pas compresser les archives ? :
#   Le plus grand volume de mes données sont des photos en jpg, qui sont donc 
#   déjà compressées. Inutile de les recompresser.
#   Les capacités/prix des disques dures USB externes d'aujourd'hui réduit
#   fortement la necessité de compression des données. 
#   La compression de fichiers augmente énormément le temps pour créer l'archive,
#   il faut donc le faire lorsque c'est vraiment necessaire.   

# A faire
#==============================================================================
# - Créer une(des) fonction(s) 'interruption'.
# - Vérifier s'il y a plus de 3 sauvegardes (nombre réglable individuellement, par partition) valide (info à la fin du script) sur le disque USB. Si c'est le cas, effacer les plus anciennes.
# - Au lancement, vérifier la dernière sauvegarde (fichier log). Si interruption sur la dernière sauvegarde, information ? Action ? 
# - ? avec la version 2.3.9 de 'dar', utiliser l'option '-q' pour masquer la synthese de l'archivage ou ajouter un argument au script pour laisser le choix.
#
# Pour le futur :
# - Copier les archives sur un disque réseau local au lieu d'un disque USB que l'on déplace d'un PC à l'autre.
# - Copier les archives du disque réseau local vers un archivage en ligne.




# >>>>> REGLAGE INITIAL 1 - DEBUT <<<<<
# Repertoire de destination sur le disque dure USB externe
#*******************************************************************************
# Emplacement sur le disque USB ou seront automatiquement créer les répertoires 
# à date pour contenir chaque saugegarde. Cet emplacement doit correspondre à un 
# PC (Netbook, AmdAthlon64, Portable_1, etc...)
# Le nom du répertoire de destination doit déjà existé sur le disque USB, il 
# n'est pas crée par le script.
# ATTENTION : éviter les espaces dans le nom de l'emplacement, utiliser le tiret 
#             milieu '-' ou le tiret bas '_'.

if [ "$1" != "test" ] ; then
	targetDir="/media/SAUVEGARDE/PC_AMD64Athlon" # <<<<< REGLAGE INITIAL
else
    targetDir="/media/EDUCLE/test-sauv" # uniquement pour tests sur clef USB
fi
# >>>>> REGLAGE INITIAL 1 - FIN <<<<<



# Taille des fichiers d'archives (optionnel - modifier uniquement si necessaire)
#*******************************************************************************
# Nota : attention, les disques USB formatés en FAT32 n'acceptent pas une taille 
# de fichier supérieure à 4 Go.
if [ "$1" != "test" ] ; then
	tailleFichierArchive="2000" # Mo (2000 = 2000 Mo = 2 Go, 3000 = 3 Go)
else
	tailleFichierArchive="100" # Mo - Pour tests sur clef USB (100 = 100 Mo = 0,1 Go)
fi




################################################################################
################################################################################
#                                  FONCTIONS 
################################################################################
################################################################################



# >>>>> REGLAGE INITIAL 2 - DEBUT <<<<<
#*******************************************************************************
# fonction - Partitions et répertoires de sauvegarde
#*******************************************************************************
# Commentaires pour les réglages :
# - Pour créer d'autre partition, copier tout un bloc existant puis modifier. Supprimer ce qui n'est pas necessaire.
# - Ne pas utiliser d'espace dans les noms qui sont créer, utiliser des '_' ou'-'. 
# - Respecter la syntaxe des chemins de répertoire et la présence ou l'absence de '/'.
# - Le chemin du répertoire du PC à archiver doit respecter l'arborescence et les noms réels.
# - Dé-commenter le début de ligne (supprimer le '#') pour créer des exclusions.
# - Les exclusions doivent respecter les noms réels des sous-répertoires.

archiver()
{
	# PARTITION PC 1 
	#----------------------------------------------------------------------------
	nomPartitionPC="Mandriva"                                      # <<<<< REGLAGE : nom de la partition PC.
	afficherTitrePartitionEtAutre # fonction
	#----------------------------------------------------------------------------
	repertoire_a_archiver="/home/famille/"                            # <<<<< REGLAGE : chemin du répertoire du PC à archiver.
	nomArchiveDar="famille"                                           # <<<<< REGLAGE : nom de l'archive sur disque USB, pour ce répertoire.
	#echo "XXXXX" >> $ZONETMP/exclusionRepertoiresEtFichiers                # <<<<< REGLAGE : nom sous-repertoire PC (XXXXX) à exclure. Un par ligne. 
	#echo "YYYYY/ZZZZZ" >> $ZONETMP/exclusionRepertoiresEtFichiers 	       # <<<<< REGLAGE : nom sous-sous-repertoire PC (ZZZZZ) à exclure. Un par ligne.
	sauvegarder # fonction  
	#----------------------------------------------------------------------------	
	


	# PARTITION PC 2 
	#----------------------------------------------------------------------------
	nomPartitionPC="WindowsXP"                                     # <<<<< REGLAGE : nom de la partition PC.
	afficherTitrePartitionEtAutre # fonction
	#-------------------------------------------------------------------------------
	repertoire_a_archiver="/Windows/Documents and Settings/venancio/" # <<<<< REGLAGE : chemin du répertoire du PC à archiver.
	nomArchiveDar="venancio"                                         # <<<<< REGLAGE : nom de l'archive sur disque USB, pour ce répertoire.
	echo "Mes documents/Ma musique" >> $ZONETMP/exclusionRepertoiresEtFichiers    
	echo "Mes documents/Downloads" >> $ZONETMP/exclusionRepertoiresEtFichiers     
	echo "Mes documents/TomTom" >> $ZONETMP/exclusionRepertoiresEtFichiers    
	echo "Bureau/Raccourci vers Elise/Ma musique" >> $ZONETMP/exclusionRepertoiresEtFichiers
	echo "Application Data/SPORE" >> $ZONETMP/exclusionRepertoiresEtFichiers
	echo "Application Data/Apple Computer" >> $ZONETMP/exclusionRepertoiresEtFichiers
	echo "Local Settings" >> $ZONETMP/exclusionRepertoiresEtFichiers
	#echo "XXXXX" >> $ZONETMP/exclusionRepertoiresEtFichiers                # <<<<< REGLAGE : nom sous-repertoire PC (XXXXX) à exclure. Un par ligne.
	#echo "YYYYY/ZZZZZ" >> $ZONETMP/exclusionRepertoiresEtFichiers 	       # <<<<< REGLAGE : nom sous-sous-repertoire PC (ZZZZZ) à exclure. Un par ligne.
	sauvegarder # fonction  
	#-------------------------------------------------------------------------------
	


	# PARTITION PC 3 
	#----------------------------------------------------------------------------
	nomPartitionPC="Sauvegard250Go"                                         # <<<<< REGLAGE : nom de la partition PC.
	afficherTitrePartitionEtAutre # fonction
	#-------------------------------------------------------------------------------
	repertoire_a_archiver="/Sauvegarde/Cécile/"                            # <<<<< REGLAGE INITIAL
	nomArchiveDar="Cecile"                                          # <<<<< REGLAGE INITIAL
	#echo "XXXXX" >> $ZONETMP/exclusionRepertoiresEtFichiers                # <<<<< REGLAGE : nom sous-repertoire PC (XXXXX) à exclure. Un par ligne.
	#echo "YYYYY/ZZZZZ" >> $ZONETMP/exclusionRepertoiresEtFichiers 	       # <<<<< REGLAGE : nom sous-sous-repertoire PC (ZZZZZ) à exclure. Un par ligne.
	sauvegarder # fonction  
	#-------------------------------------------------------------------------------
	repertoire_a_archiver="/Sauvegarde/David/" # <<<<< REGLAGE INITIAL
	nomArchiveDar="David"                                         # <<<<< REGLAGE INITIAL
	#echo "XXXXX" >> $ZONETMP/exclusionRepertoiresEtFichiers                # <<<<< REGLAGE : nom sous-repertoire PC (XXXXX) à exclure. Un par ligne.
	#echo "YYYYY/ZZZZZ" >> $ZONETMP/exclusionRepertoiresEtFichiers 	       # <<<<< REGLAGE : nom sous-sous-repertoire PC (ZZZZZ) à exclure. Un par ligne.
	sauvegarder # fonction  
	#-------------------------------------------------------------------------------
	repertoire_a_archiver="/Sauvegarde/Laure/" # <<<<< REGLAGE INITIAL
	nomArchiveDar="Laure"                                         # <<<<< REGLAGE INITIAL
	#echo "XXXXX" >> $ZONETMP/exclusionRepertoiresEtFichiers                # <<<<< REGLAGE : nom sous-repertoire PC (XXXXX) à exclure. Un par ligne.
	#echo "YYYYY/ZZZZZ" >> $ZONETMP/exclusionRepertoiresEtFichiers 	       # <<<<< REGLAGE : nom sous-sous-repertoire PC (ZZZZZ) à exclure. Un par ligne.
	sauvegarder # fonction  
	#-------------------------------------------------------------------------------
	repertoire_a_archiver="/Sauvegarde/Maman/" # <<<<< REGLAGE INITIAL
	nomArchiveDar="Maman"                                         # <<<<< REGLAGE INITIAL
	#echo "XXXXX" >> $ZONETMP/exclusionRepertoiresEtFichiers                # <<<<< REGLAGE : nom sous-repertoire PC (XXXXX) à exclure. Un par ligne.
	#echo "YYYYY/ZZZZZ" >> $ZONETMP/exclusionRepertoiresEtFichiers 	       # <<<<< REGLAGE : nom sous-sous-repertoire PC (ZZZZZ) à exclure. Un par ligne.
	sauvegarder # fonction  
	#-------------------------------------------------------------------------------
	repertoire_a_archiver="/Sauvegarde/Papa/" # <<<<< REGLAGE INITIAL
	nomArchiveDar="Papa"                                         # <<<<< REGLAGE INITIAL
	#echo "XXXXX" >> $ZONETMP/exclusionRepertoiresEtFichiers                # <<<<< REGLAGE : nom sous-repertoire PC (XXXXX) à exclure. Un par ligne.
	#echo "YYYYY/ZZZZZ" >> $ZONETMP/exclusionRepertoiresEtFichiers 	       # <<<<< REGLAGE : nom sous-sous-repertoire PC (ZZZZZ) à exclure. Un par ligne.
	sauvegarder # fonction  
	#-------------------------------------------------------------------------------
	repertoire_a_archiver="/Sauvegarde/Images_Ne-pas-toucher_Linux/" # <<<<< REGLAGE INITIAL
	nomArchiveDar="Images_Ne-pas-tou_Linux"                                         # <<<<< REGLAGE INITIAL
	#echo "XXXXX" >> $ZONETMP/exclusionRepertoiresEtFichiers                # <<<<< REGLAGE : nom sous-repertoire PC (XXXXX) à exclure. Un par ligne.
	#echo "YYYYY/ZZZZZ" >> $ZONETMP/exclusionRepertoiresEtFichiers 	       # <<<<< REGLAGE : nom sous-sous-repertoire PC (ZZZZZ) à exclure. Un par ligne.
	sauvegarder # fonction  
	#-------------------------------------------------------------------------------
}
# >>>>> REGLAGE INITIAL 2 - FIN <<<<<




# >>>>> REGLAGE INITIAL 3 - DEBUT <<<<<
#*******************************************************************************
# fonction - Liste des type (extensions) de fichiers à exclure
#*******************************************************************************
typeFichiers_a_exclure()
{
	# Pour ajouter d'autres exclusions, ajouter des lignes en respectant la syntaxe
	echo "*.*~" >> $ZONETMP/exclusionTypesFichier   # Fichiers temporaires
	echo "*~" >> $ZONETMP/exclusionTypesFichier     # Fichiers temporaires
	echo "*.dar" >> $ZONETMP/exclusionTypesFichier  # Fichiers 'Dar'
	echo "*.iso" >> $ZONETMP/exclusionTypesFichier  # Images des CD/DVD
}
# >>>>> REGLAGE INITIAL 3 - FIN <<<<<




#*******************************************************************************
# fonction - Partitions et répertoires de sauvegarde pour test sur
#            un clef USB au lieu d'un disque USB
#*******************************************************************************
archiverTestSurClefUsb()
{
	# PARTITION PC 1 
	#-------------------------------------------------------------------------------
	nomPartitionPC="Mandriva"
	afficherTitrePartitionEtAutre # fonction
	#-------------------------------------------------------------------------------
	repertoire_a_archiver="/home/papa/rpm/"
	nomArchiveDar="rpm"
	echo "BUILD" >> $ZONETMP/exclusionRepertoiresEtFichiers
	echo "SOURCES" >> $ZONETMP/exclusionRepertoiresEtFichiers
	echo "RPMS/i586" >> $ZONETMP/exclusionRepertoiresEtFichiers
	sauvegarder $1 $2 # fonction
	#-------------------------------------------------------------------------------
	repertoire_a_archiver="/home/papa/.thunderbird/"
	nomArchiveDar="thunderbird"
	#echo "XXXXX" >> $ZONETMP/exclusionRepertoiresEtFichiers  
	#echo "YYYYY/ZZZZZ" >> $ZONETMP/exclusionRepertoiresEtFichiers 
	sauvegarder $1 $2 # fonction
	#-------------------------------------------------------------------------------



	# PARTITION PC 2
	#-------------------------------------------------------------------------------
	nomPartitionPC="WindowsXP"
	afficherTitrePartitionEtAutre # fonction
	#-------------------------------------------------------------------------------
	repertoire_a_archiver="/mnt/windows/Documents and Settings/Rafael Venancio/Bureau/"
	nomArchiveDar="Bureau"
	#echo "XXXXX" >> $ZONETMP/exclusionRepertoiresEtFichiers
	#echo "YYYYY/ZZZZZ" >> $ZONETMP/exclusionRepertoiresEtFichiers 
	sauvegarder $1 $2 # fonction
	#-------------------------------------------------------------------------------
	repertoire_a_archiver="/mnt/windows/Documents and Settings/Rafael Venancio/Mes documents/"
	nomArchiveDar="MesDocuments"
	#echo "XXXXX" >> $ZONETMP/exclusionRepertoiresEtFichiers
	#echo "YYYYY/ZZZZZ" >> $ZONETMP/exclusionRepertoiresEtFichiers
	sauvegarder $1 $2 # fonction
	#-------------------------------------------------------------------------------



	# PARTITION PC 3
	#-------------------------------------------------------------------------------	
	nomPartitionPC="Disque"
	afficherTitrePartitionEtAutre # fonction
	#-------------------------------------------------------------------------------
	repertoire_a_archiver="/mnt/Disque/Documents/Wind U100/"
	nomArchiveDar="Wind_U100"
	echo "Fond ecran" >> $ZONETMP/exclusionRepertoiresEtFichiers
	#echo "XXXXX" >> $ZONETMP/exclusionRepertoiresEtFichiers
	#echo "YYYYY/ZZZZZ" >> $ZONETMP/exclusionRepertoiresEtFichiers
	sauvegarder $1 $2 # fonction
	#-------------------------------------------------------------------------------
}




#*******************************************************************************
# fonction - complétion du fichier de commande pour dar
#*******************************************************************************
creerCommandeDar()
{
	TESTPRESENCE="false"
	echo "-c $ZONETMP/$nomArchiveDar" >> $ZONETMP/commandeDar # Nom de l'archive à créer

	echo "-R \"$repertoire_a_archiver\"" >> $ZONETMP/commandeDar # Répetoire du PC à archiver
	echo "-w" >> $ZONETMP/commandeDar # Je ne me souvient plus. Voir la doc.
	echo "-s $tailleFichierArchive" >> $ZONETMP/commandeDar # Taille maximum d'un fichier d'archive
	echo "-D" >> $ZONETMP/commandeDar  # Je ne me souvient plus. Voir la doc.
	echo "--exclude-from-file $ZONETMP/exclusionRepertoiresEtFichiers" >> $ZONETMP/commandeDar # Répertoires à exclure
	echo "-E \"./$scriptSousProgramme %b %n $formatFichier $targetDir $backupDir $nomPartitionPC $ZONETMP $TESTPRESENCE\"" >> $ZONETMP/commandeDar # Appel du script de sous-programme à la fin de chaque création de fichier de 2 Go. 

	#	echo "-q" >> $ZONETMP/commandeDar # option 'quiet' disponible uniquement à partir de la version 2.3.9 de 'dar'

	# exclusion des type de fichiers
	while read line
	do
		echo -e "-X \"$line\" " >> $ZONETMP/commandeDar
	done < $ZONETMP/exclusionTypesFichier
}




#*******************************************************************************
# fonction - Création de sous-répertoire sur le disque USB 
#*******************************************************************************
creerSousRepertoireSurUSB()
{
	echo -n "Création sous-répertoire '$nomPartitionPC' sur disque USB... " | tee -a $fichierLog

	# Vérifier si le répertoire à créer sur le disque USB exite déjà
	if [ -d "$targetDir/$backupDir/$nomPartitionPC" ]; then 
		echo " " | tee -a $fichierLog
		echo "Le répertoire '$nomPartitionPC' existe déjà sur le disque USB" | tee -a $fichierLog
		read -p "    -> Poursuivre en ajoutant les fichiers dans ce répertoire ? [o]ui  [n]on " ERR1
		echo "    -> Poursuivre en ajoutant les fichiers dans ce répertoire ? [o]ui  [n]on : $ERR1" >> $fichierLog
		if [ "$ERR1" != "o" ] ; then
			echo " " | tee -a $fichierLog
			echo "Interruption du script." | tee -a $fichierLog
			echo "Aucune action réalisée. Corriger manuellement et relancer le script" | tee -a $fichierLog
			echo " " | tee -a $fichierLog
			echo " " | tee -a $fichierLog
			echo " " | tee -a $fichierLog
			rm -r -f "$ZONETMP" # Effacer le répertoire temporaire
			setterm -cursor on # Demasquage du curseur
			exit 0
		fi
	else
		mkdir "$targetDir/$backupDir/$nomPartitionPC"
		if [ "$?" == "0" ]; then # le '$?' == code sortie de la dernière commande'
			echo "OK" | tee -a $fichierLog
		else
			echo "echec" | tee -a $fichierLog
			echo " " | tee -a $fichierLog
			echo "Interruption du script." | tee -a $fichierLog
			echo "Vérifier la cause de la non création du répertoire" | tee -a $fichierLog 
			echo " " | tee -a $fichierLog
			echo " " | tee -a $fichierLog
			echo " " | tee -a $fichierLog
			rm -r -f "$ZONETMP" # Effacer le répertoire temporaire
			setterm -cursor on # Demasquage du curseur
			exit 1

		fi
	fi
}




#*******************************************************************************
# fonction - Affichage titres des partitions et autres actions
#*******************************************************************************
afficherTitrePartitionEtAutre()
{
	verifierLongeurNomPartition # fonction

	if [ "$verificationEspaceDisque" != "true" ] ; then
		echo " " | tee -a $fichierLog
		echo " " | tee -a $fichierLog
		echo "**************************************************************************" | tee -a $fichierLog
		echo -n "                 partition '$nomPartitionPC'" | tee -a $fichierLog

		if [ "$test" == "true" ] ; then
			echo " -> clef USB" | tee -a $fichierLog
		else
			echo " " | tee -a $fichierLog
		fi

		echo "**************************************************************************" | tee -a $fichierLog

		creerSousRepertoireSurUSB # Fonction
	fi
}




#*******************************************************************************
# fonction - Sauvegarde 
#*******************************************************************************
sauvegarder()
{
	verifierLongeurNomArchiveDar # fonction

	> $ZONETMP/exclusionTypesFichier # Création fichier des type de fichier (*.mp3, *.iso, etc..) à exclure
	typeFichiers_a_exclure # fonction - complétion du fichier des type de fichiers à exclure

	if [ "$verificationEspaceDisque" == "true" ] ; then

		if [ "$nomPartitionPC" == "$nomPartitionOld" ] ; then
			echo -n "            " | tee -a $fichierLog
			printf "%-"$longueurMaxiNomPartition"s %s" " " | tee -a $fichierLog
		else
			echo -n "- partition " | tee -a $fichierLog
			printf "%-"$longueurMaxiNomPartition"s %s" "'$nomPartitionPC'" | tee -a $fichierLog
		fi
		echo -n " repert. " | tee -a $fichierLog
		printf "%-"$longueurMaxiNomArchiveDar"s %s" "'$nomArchiveDar'" | tee -a $fichierLog
		echo -n "... " | tee -a $fichierLog
		nomPartitionOld="$nomPartitionPC" 

		# Occupation disque
		occupationDisqueRepertoirePc=`du -s -k --exclude-from=$ZONETMP/exclusionRepertoiresEtFichiers --exclude-from=$ZONETMP/exclusionTypesFichier "$repertoire_a_archiver" | awk '{print $1}'`

		occupationDisqueRepertoirePcTotal=`expr $occupationDisqueRepertoirePcTotal + $occupationDisqueRepertoirePc`

		afficherTaille $occupationDisqueRepertoirePc 2 # fonction
	
	else
		echo " "  | tee -a $fichierLog
		echo "Archive : $nomArchiveDar" | tee -a $fichierLog
		echo "--------------------------------------------------------------------------" | tee -a $fichierLog

		# archivage
		> $ZONETMP/commandeDar # création fichier de commande pour 'dar'
		creerCommandeDar # fonction - complétion du fichier de commande pour 'dar'

		dar -B $ZONETMP/commandeDar | tee -a $fichierLog

		rm $ZONETMP/commandeDar

		creerFichierSha1Archive # fonction

	fi

	rm $ZONETMP/exclusionTypesFichier
}




#*******************************************************************************
# fonction - Création du fichier sha1 de l'ensemble des fichiers d'une archive
#            Pour pouvoir vérifier (sha1) tous les fichiers d'une archive en une fois, manuellement
#*******************************************************************************
creerFichierSha1Archive()
{
	# Création d'un fichier avec les nom des différents fichiers sha1 d'une archive
	find "$targetDir/$backupDir/$nomPartitionPC/" -name "$nomArchiveDar.*.sha1" -type f > fichiersSurPC
	exec 3<fichiersSurPC # Stockage du fichier dans un buffer

	# Création d'un fichier avec les codes et noms, formaté pour le 'sha1sum -c ....'
	while read ligneFichiersSurPC 0<&3
	do
		fichierPC=${ligneFichiersSurPC##*\/} # extraction du nom de fichier, sans l'arboresence

		# lecture les mots 1 et 2 
		while IFS=: read codeSha1 nomFichier 
		do
			echo -e "$codeSha1 $nomFichier" >> "tempo"
		done < "$targetDir/$backupDir/$nomPartitionPC/$fichierPC"
	done 

	# Suppression des espaces en fin de ligne (sinon la cde 'sha1sum -c ...' ne fonctionne pas)
	sed 's/ *$//g' "tempo" > "$targetDir/$backupDir/$nomPartitionPC/$nomArchiveDar.sha1" 

	rm fichiersSurPC
	rm tempo
}




#*******************************************************************************
# fonction - afficher automatiquement l'unité d'espace disque la plus 
#            pertinente : ko, Mo, Go, To
#*******************************************************************************
afficherTaille()
{
	# $1 = valeur à afficher
	# $2 = nombre de décimale

	if [ "$1" -gt "1000000000" ] ; then
		valeur=$(echo "scale=$2; $1/1000000000" | bc -l)
		printf "%7s" $valeur | tee -a $fichierLog
		echo " To" | tee -a $fichierLog
	else
		if [ "$1" -gt "1000000" ] ; then
			valeur=$(echo "scale=$2; $1/1000000" | bc -l)
			printf "%7s" $valeur | tee -a $fichierLog
			echo " Go" | tee -a $fichierLog
		else
			if [ "$1" -gt "1000" ] ; then
				valeur=$(echo "scale=$2; $1/1000" | bc -l)
				printf "%7s" $valeur | tee -a $fichierLog
				echo " Mo" | tee -a $fichierLog
			else
				valeur=$(echo "scale=$2; $1/1" | bc -l)
				printf "%7s" $valeur | tee -a $fichierLog
				echo " Ko" | tee -a $fichierLog
			fi
		fi
	fi
}




#*******************************************************************************
# fonction - vérifier la longueur du nom de partition '$nomPartitionPC'
#*******************************************************************************
verifierLongeurNomPartition()
{
	longueurNomdiskDir=`expr length $nomPartitionPC`
	valeur=`expr $longueurMaxiNomPartition - 2` # Correction de 2 semble necessaire. 

	if [ $longueurNomdiskDir -gt $valeur ]; then
		echo " " | tee -a $fichierLog		
		echo "Interruption du script." | tee -a $fichierLog
		echo "- Le nom de partition '$nomPartitionPC' est trop long ($longueurNomdiskDir)." | tee -a $fichierLog 
		echo "- Maximum autorisé : $valeur caractères." | tee -a $fichierLog 
		echo "- Racourcir le non de la partition." | tee -a $fichierLog 
		echo " " | tee -a $fichierLog
		echo " " | tee -a $fichierLog
		echo " " | tee -a $fichierLog
		rm -r -f "$ZONETMP" # Effacer le répertoire temporaire
		setterm -cursor on # Demasquage du curseur
		exit 1
	fi
}




#*******************************************************************************
# fonction - vérifier la longueur du nom de l'archive '$nomArchiveDar'
#*******************************************************************************
verifierLongeurNomArchiveDar()
{
	longueurNomArchiveDar=`expr length $nomArchiveDar`
	valeur=`expr $longueurMaxiNomArchiveDar - 2` # Correction de 2 semble necessaire. 

	if [ $longueurNomArchiveDar -gt $valeur ]; then
		echo " " | tee -a $fichierLog		
		echo "Interruption du script." | tee -a $fichierLog
		echo "- Le nom de l'archive '$nomArchiveDar' est trop long ($longueurNomArchiveDar)." | tee -a $fichierLog 
		echo "- Maximum autorisé : $valeur caractères." | tee -a $fichierLog 
		echo "- Racourcir le non de l'archive." | tee -a $fichierLog 
		echo " " | tee -a $fichierLog
		echo " " | tee -a $fichierLog
		echo " " | tee -a $fichierLog
		rm -r -f "$ZONETMP" # Effacer le répertoire temporaire
		setterm -cursor on # Demasquage du curseur
		exit 1
	fi
}




#*******************************************************************************
# fonction - vérifier qu'une variable est strictement numérique (un chiffre)
#*******************************************************************************
# Repris du site web
# http://www.linuxtopia.org/online_books/advanced_bash_scripting_guide/testbranch.html
isdigit()    # Tests whether *entire string* is numerical.
{             # In other words, tests for integer variable.
	[ $# -eq 1 ] || return "1" # Echec

	case $1 in
	*[!0-9]*|"") return "1";; # Echec
	          *) return "0";; # Succès
	esac
}







################################################################################
################################################################################
#                                 FLUX PRINCIPAL
################################################################################
################################################################################

# Réglages _____________________________________________________________________
longueurMaxiNomPartition=16 # Longueur maximum du nom de la partition
longueurMaxiNomArchiveDar=25 # Longueur maximum du non de l'arcvive.
# Ces longueurs de nom sont importantes pour la mise en page de l'affichage des 
# occupation disques PC des archives.


# Variables ____________________________________________________________________
formatFichier="dar" # Extension du fichier Dar
DATE=`date -I` # Date au format AAAA-MM-JJ
DATEHEURE="`date -I`_`date +%H%M%S`" # Format AAAA-MM-JJ_hhmmss

scriptSousProgramme="SauvegardeGeneralePC_SousProgr1.sh"

fichierLog="./sauvegardeGeneralePC_$DATEHEURE.log" # Création du fichier de log



echo "**************************************************************************" | tee -a $fichierLog
echo "*   Script d'archivage et copie des fichiers sur un disque USB externe   *" | tee -a $fichierLog 
echo "*                                                                        *" | tee -a $fichierLog 
echo "*                Rafael Venancio rafael.venan@free.fr                    *" | tee -a $fichierLog 
echo "**************************************************************************" | tee -a $fichierLog 
echo "                `date +%A` `date +%d` `date +%B` `date +%Y` - `date +%H`:`date +%M`:`date +%S` " | tee -a $fichierLog 




#*******************************************************************************
# Création des fichiers et répertoires nécessaires
#*******************************************************************************

# Création répertoire temporaire local _________________________________________
ZONETMP="./.tmp" # Zone ou sont crées localement les archives et les fichiers temporaires 

rm -r -f "$ZONETMP" # Effacer le répertoire temporaire précedent, s'il est présent
mkdir "$ZONETMP"
if [ "$?" != "0" ]; then # le '$?' == code sortie de la dernière commande'
	echo " " | tee -a $fichierLog | tee -a $fichierLog
	echo "Echec création répertoire temporaire '$ZONETMP'" | tee -a $fichierLog
	echo "Vérifier la cause de la non création du répertoire" | tee -a $fichierLog
	echo " " | tee -a $fichierLog
	echo "Interruption du script." | tee -a $fichierLog
	echo " " | tee -a $fichierLog
	echo " " | tee -a $fichierLog
	echo " " | tee -a $fichierLog	
	rm "$fichierLog" # Effacer fichier de log
	setterm -cursor on # Demasquage du curseur
	exit 1
fi


# Fichiers pour exclusions des commandes 'dar' et 'du' (disk usage)
#cd $ZONETMP
#> exclusionRepertoiresEtFichiers # Noms (désignation) des répertoires et fichiers
#cd /.
> $ZONETMP/exclusionRepertoiresEtFichiers # Noms (désignation) des répertoires et fichiers





#*******************************************************************************
# Vérification des requis 
#*******************************************************************************
requisOK='true'

echo " " | tee -a $fichierLog
echo -n "Vérification installation et présence des requis... " | tee -a $fichierLog

# Installation sha1sum _________________________________________________________
sha1sum --help >/dev/null 2>&1
codeSortie=$? # le '$?' == code sortie de la dernière commande'
if [ "$codeSortie" -ne "0" ]; then 
	echo "echec " | tee -a $fichierLog
	echo "- 'sha1sum' n'est pas installé." | tee -a $fichierLog
	requisOK="false"
fi


# Installation 'bc' ____________________________________________________________
bc --help >/dev/null 2>&1
codeSortie=$? # le '$?' == code sortie de la dernière commande'
if [ "$codeSortie" -ne "0" ]; then
	if [ "$requisOK" == "true" ]; then
		echo "echec " | tee -a $fichierLog
	fi
	echo "- le logiciel 'bc' n'est pas installé." | tee -a $fichierLog
	requisOK="false"
fi


# Installation 'dar' ___________________________________________________________
dar -h >/dev/null 2>&1
codeSortie=$? # le '$?' == code sortie de la dernière commande'
if [ "$codeSortie" -gt "11" ]; then 
	if [ "$requisOK" == "true" ]; then
		echo "echec " | tee -a $fichierLog
	fi
	echo "- le logiciel 'dar' n'est pas installé." | tee -a $fichierLog
	requisOK="false"
fi


# Présence script de sous-programme ____________________________________________
TESTPRESENCE="true"
sh $scriptSousProgramme "toto" "toto" "toto" "toto" "toto" "toto" "toto" $TESTPRESENCE >/dev/null 2>&1
codeSortie=$? # le '$?' == code sortie de la dernière commande'
if [ "$codeSortie" -ne "0" ]; then
	if [ "$requisOK" == "true" ]; then
		echo "echec " | tee -a $fichierLog
	fi
	echo "- le sous-programme '$scriptSousProgramme' est absent." | tee -a $fichierLog
	requisOK="false"
fi


# le script de sous-programme est executable ___________________________________
chmod a+x $scriptSousProgramme >/dev/null 2>&1 # Je tente de rendre le script executable
 
permissions=`ls -l "$scriptSousProgramme" | awk '{print $1}'` # '$1' représente le 1er élement de la ligne 'ls ...'

permissionExecutable1=${permissions:3:1} # extrait 1 caractère à partir du 4ème (indice 3)
permissionExecutable2=${permissions:6:1} # extrait 1 caractère à partir du 7ème (indice 6)
permissionExecutable3=${permissions:9:1} # extrait 1 caractère à partir du 10ème (indice 9)
synthesePermissionsExecutable="$permissionExecutable1$permissionExecutable2$permissionExecutable3"

if [ "$synthesePermissionsExecutable" != "xxx" ]; then
	if [ "$requisOK" == "true" ]; then
		echo "echec " | tee -a $fichierLog
	fi
	echo "- le sous-programme '$scriptSousProgramme' n'est pas executable." | tee -a $fichierLog
	echo "  Impossible de le modifier automatiquement. Rendez-le executable manuellement." | tee -a $fichierLog
	requisOK="false"
fi


# affichage en cas d'echec _____________________________________________________
if [ "$requisOK" != "true" ]; then 
	echo " " | tee -a $fichierLog
	echo "Interruption du script." | tee -a $fichierLog
	echo " " | tee -a $fichierLog
	echo " " | tee -a $fichierLog
	echo " " | tee -a $fichierLog
	rm "$fichierLog" # Effacer fichier de log
	rm -r -f "$ZONETMP" # Effacer le répertoire temporaire
	setterm -cursor on # Demasquage du curseur
	exit 0
else
	echo "OK"  | tee -a $fichierLog
fi




#*******************************************************************************
# Vérification que l'espace disque libre du PC est suffisant pour creer les 
# fichiers d'archives
#*******************************************************************************
echo " " | tee -a $fichierLog
echo -n "Vérification espace disponible sur PC pour création fichiers archives... " | tee -a $fichierLog

espaceDisponibleDisquePcMini=`expr $tailleFichierArchive \\* 2 \\* 1000` # coefficient 2 et conversion en Kb

# Mesure espaceDisponibleDisquePc
valeurBrute=`df -k "$ZONETMP" | grep % | awk '{print $4}'` # '$4' représente le 4ème élement de la ligne 'df -k'
espaceDisponibleDisquePc=`echo $valeurBrute | awk '{print $1}'` # extraction 1er élement de la ligne (éventuellement titre)

# Conversion du retour de la commande 'df' suivant format : avec colonne des titres ou uniquement la valeur 
isdigit "$espaceDisponibleDisquePc" # fonction
if [ "$?" != "0" ]; then
  espaceDisponibleDisquePc=`echo $valeurBrute | awk '{print $2}'` # extraction 2ème élement de la ligne
fi



if [ $espaceDisponibleDisquePcMini -gt $espaceDisponibleDisquePc ]; then
	echo "échec" | tee -a $fichierLog

	echo -n "- Espace disponible sur disque PC, répertoire '$ZONETMP' : " | tee -a $fichierLog
	afficherTaille $espaceDisponibleDisquePc 2 # fonction

	espaceDisquePcManquant=`expr $espaceDisponibleDisquePcMini - $espaceDisponibleDisquePc`

	echo -n "- Besoin espace disponible minimum                                : " | tee -a $fichierLog
	afficherTaille $espaceDisponibleDisquePcMini 2 # fonction

	echo -n "- Il manque                                                       : " | tee -a $fichierLog
	afficherTaille $espaceDisquePcManquant 2 # fonction

	echo -n "- Rappel : taille maximum des fichiers archive                    : " | tee -a $fichierLog
	afficherTaille `expr $tailleFichierArchive \\* 1000` 2 # fonction et conversion en Kb

	echo " " | tee -a $fichierLog
	echo "Interruption du script." | tee -a $fichierLog
	echo " " | tee -a $fichierLog
	echo " " | tee -a $fichierLog
	echo " " | tee -a $fichierLog
	rm "$fichierLog" # Effacer fichier de log
	rm -r -f "$ZONETMP" # Effacer le répertoire temporaire
	setterm -cursor on # Demasquage du curseur
	exit 0	
fi

echo "OK" | tee -a $fichierLog

echo -n "- Espace disponible sur disque PC, répertoire '$ZONETMP' : " | tee -a $fichierLog
afficherTaille $espaceDisponibleDisquePc 2 # fonction




#*******************************************************************************
# Confirmation branchement et reconnaissance du disque USB
#*******************************************************************************
echo " " | tee -a $fichierLog
echo "Connecter et allumer le disque dur USB externe" | tee -a $fichierLog
echo "Attention ! attendre qu'il soit reconnu par le système avant de poursuivre" | tee -a $fichierLog

read -p "    -> confirmation disque dur USB disponible ? [o]ui  [n]on : " ERR3
echo "    -> confirmation disque dur USB disponible ? [o]ui  [n]on : $ERR3" >> $fichierLog

if [ "$ERR3" != "o" ] ; then
	echo " " | tee -a $fichierLog
	echo "Interruption du script." | tee -a $fichierLog
	echo "Aucune action réalisée." | tee -a $fichierLog
	echo " " | tee -a $fichierLog
	echo " " | tee -a $fichierLog
	echo " " | tee -a $fichierLog
	rm "$fichierLog" # Effacer fichier de log
	rm -r -f "$ZONETMP" # Effacer le répertoire temporaire
	setterm -cursor on # Demasquage du curseur
	exit 0
fi




#*******************************************************************************
# Vérification présence arboresence pour ce PC sur le disque USB
#*******************************************************************************
echo " " | tee -a $fichierLog
echo "Vérification arboresence pour ce PC sur le disque USB" | tee -a $fichierLog

echo -n "'$targetDir'... " | tee -a $fichierLog

if [ -d "$targetDir" ]; then
	echo "OK"  | tee -a $fichierLog
else
	echo "echec" | tee -a $fichierLog
	echo " " | tee -a $fichierLog
	echo "Causes probables :" | tee -a $fichierLog
	echo "- chemin jusqu'au disque dur USB non valable." | tee -a $fichierLog
	echo "- nom du disque dur USB reconnu par le systeme, non valable" | tee -a $fichierLog
	echo "- nom du PC sur le disque dur USB incorrect ou absent." | tee -a $fichierLog
	echo " " | tee -a $fichierLog
	echo "Vérifier 'REGLAGE INITIAL 1' dans le script."  | tee -a $fichierLog
	echo " " | tee -a $fichierLog
	echo "Interruption du script." | tee -a $fichierLog
	echo " " | tee -a $fichierLog
	echo " " | tee -a $fichierLog
	echo " " | tee -a $fichierLog
	rm "$fichierLog" # Effacer fichier de log
	rm -r -f "$ZONETMP" # Effacer le répertoire temporaire
	setterm -cursor on # Demasquage du curseur
	exit 1
fi




#*******************************************************************************
# Calcul occupation disque de la sauvegarde
#*******************************************************************************
setterm -cursor off # Masquage du curseur

echo " " | tee -a $fichierLog
echo "Calcul occupation disque de la sauvegarde" | tee -a $fichierLog


# Espace minimum autorisé sur les disque USB après la sauvegarde _______________
espaceDisqueDisponibleFinaleMiniAdm=`expr $tailleFichierArchive \\* 3 \\* 1000` # coefficient 3 et conversion en kb


# Calcul des occupation disque des répertoires à sauvegarder ___________________
occupationDisqueRepertoirePcTotal="0"

verificationEspaceDisque="true" # pour réaliser le calcul d'espace disque au lieu d'un archivage
nomPartitionOld=" "
if [ "$1" != "test" ] ; then
	archiver # fonction
else
	archiverTestSurClefUsb $1 $2 # fonction 'archiver' pour tests avec clef USB
fi
verificationEspaceDisque="false" # pour les prochains archivages soient réels

echo -n "Prévision occupation disque de la sauvegarde                  total " | tee -a $fichierLog
afficherTaille $occupationDisqueRepertoirePcTotal 2 # fonction




#*******************************************************************************
# Vérification espace disponible suffisant sur le disque USB
#*******************************************************************************
echo " " | tee -a $fichierLog
echo -n "Verification espace disponible disque USB... " | tee -a $fichierLog

occupationDisqueUsb=`du -s -k "$targetDir" | awk '{print $1}'`


# Mesure espaceDisponibleDisqueUsb
valeurBrute=`df -k "$targetDir" | grep % | awk '{print $4}'` # '$4' représente le 4ème élement de la ligne 'df -k'
espaceDisponibleDisqueUsb=`echo $valeurBrute | awk '{print $1}'` # extraction 1er élement de la ligne (éventuellement titre)

# Conversion du retour de la commande 'df' suivant format : avec colonne des titres ou uniquement la valeur 
isdigit "$espaceDisponibleDisqueUsb" # fonction
if [ "$?" != "0" ]; then
	espaceDisponibleDisqueUsb=`echo $valeurBrute | awk '{print $2}'` # extraction 2ème élement de la ligne
fi


capaciteMaxiDisqueUsb=`expr $espaceDisponibleDisqueUsb + $occupationDisqueUsb`

previsionEspaceTotalDisqueUsbFinale=`expr $occupationDisqueUsb + $occupationDisqueRepertoirePcTotal + $espaceDisqueDisponibleFinaleMiniAdm`

previsionEspaceDisponibleDisqueUsbFinale=`expr $espaceDisponibleDisqueUsb - $occupationDisqueRepertoirePcTotal`

if [ $previsionEspaceTotalDisqueUsbFinale -gt $capaciteMaxiDisqueUsb ]; then
	echo "échec" | tee -a $fichierLog

	echo -n "- Espace disponible sur disque USB                                : " | tee -a $fichierLog
	afficherTaille $espaceDisponibleDisqueUsb 2 # fonction

	espaceDisqueUsbManquant=`expr $occupationDisqueRepertoirePcTotal - $espaceDisponibleDisqueUsb + $espaceDisqueDisponibleFinaleMiniAdm`

	echo -n "- Il manque                                                       : " | tee -a $fichierLog
	afficherTaille $espaceDisqueUsbManquant 2 # fonction

	echo " " | tee -a $fichierLog
	echo "Interruption du script." | tee -a $fichierLog
	echo " " | tee -a $fichierLog
	echo " " | tee -a $fichierLog
	echo " " | tee -a $fichierLog
	rm "$fichierLog" # Effacer fichier de log
	rm -r -f "$ZONETMP" # Effacer le répertoire temporaire
	setterm -cursor on # Demasquage du curseur
	exit 0	
fi

echo "OK" | tee -a $fichierLog

echo -n "- Espace disponible sur disque USB                                : " | tee -a $fichierLog
afficherTaille $espaceDisponibleDisqueUsb 2 # fonction

echo -n "- Prevision espace disponible sur disque USB après la sauvegarde  : " | tee -a $fichierLog
afficherTaille $previsionEspaceDisponibleDisqueUsbFinale 2 # fonction

setterm -cursor on # Demasquage du curseur

read -p "    -> Lancer la sauvegarde ? [o]ui  [n]on : " ERR1
echo "    -> Lancer la sauvegarde ? [o]ui  [n]on : $ERR1" >> $fichierLog
if [ "$ERR1" != "o" ] ; then
	echo " " | tee -a $fichierLog
	echo "Interruption du script." | tee -a $fichierLog
	echo "Aucune action réalisée." | tee -a $fichierLog
	echo " " | tee -a $fichierLog
	echo " " | tee -a $fichierLog
	echo " " | tee -a $fichierLog
	rm "$fichierLog" # Effacer fichier de log
	rm -r -f "$ZONETMP" # Effacer le répertoire temporaire	
	setterm -cursor on # Demasquage du curseur
	exit 0
fi




#*******************************************************************************
# Création répertoire de sauvegarde sur le disque USB
#*******************************************************************************
backupDir="Sauvg_$DATE"
echo " " | tee -a $fichierLog
echo -n "Création répertoire '$backupDir' sur disque USB... " | tee -a $fichierLog

if [ -d "$targetDir/$backupDir" ]; then # Vérifier si le répertoire à créer sur le disque USB exite déjà
	echo " "  | tee -a $fichierLog
	echo "Le répertoire '$backupDir' existe déjà sur le disque USB" | tee -a $fichierLog
	read -p "    -> Poursuivre en ajoutant les fichiers dans ce répertoire ? [o]ui  [n]on " ERR1
	echo "    -> Poursuivre en ajoutant les fichiers dans ce répertoire ? [o]ui  [n]on : $ERR1" >> $fichierLog

	if [ "$ERR1" != "o" ] ; then
		echo " "  | tee -a $fichierLog
		echo "Interruption du script." | tee -a $fichierLog
		echo "Aucune action réalisée. Corriger manuellement et relancer le script" | tee -a $fichierLog
		echo " " | tee -a $fichierLog
		echo " " | tee -a $fichierLog
		echo " " | tee -a $fichierLog
		rm "$fichierLog" # Effacer fichier de log
		rm -r -f "$ZONETMP" # Effacer le répertoire temporaire		
		setterm -cursor on # Demasquage du curseur
		exit 0
	fi
else
	mkdir "$targetDir/$backupDir"
	if [ "$?" == "0" ]; then # le '$?' == code sortie de la dernière commande'
		echo "OK" | tee -a $fichierLog
	else
		echo "echec" | tee -a $fichierLog
		echo " " | tee -a $fichierLog
		echo "Interruption du script." | tee -a $fichierLog
		echo "Vérifier la cause de la non création du répertoire" | tee -a $fichierLog 
		echo " " | tee -a $fichierLog
		echo " " | tee -a $fichierLog
		echo " " | tee -a $fichierLog
		rm "$fichierLog" # Effacer fichier de log
		rm -r -f "$ZONETMP" # Effacer le répertoire temporaire		
		setterm -cursor on # Demasquage du curseur
		exit 1
	fi
fi




#*******************************************************************************
# Sauvegarde
#*******************************************************************************
echo " " | tee -a $fichierLog
echo " >>>> Début du fonctionnement automatique du script" | tee -a $fichierLog
echo "      Durée d'execution très variables. Vous pouvez faire autre chose " | tee -a $fichierLog
echo "      pendant ce temps" | tee -a $fichierLog

start_time=$(date +%s)
setterm -cursor off # Masquage du curseur

tailleFichierArchive="${tailleFichierArchive}M" # ajout du 'M' pour attribut commande dar

if [ "$1" == "test" ] ; then
	test="true"
else
	test="false"
fi

if [ "$test" == "true" ] ; then
	archiverTestSurClefUsb # fonction 'archiver' pour tests avec clef USB
else
	archiver # fonction 'archiver' normal
fi




#*******************************************************************************
# Fin du script
#*******************************************************************************
echo " " | tee -a $fichierLog
echo " " | tee -a $fichierLog
echo "**************************************************************************" | tee -a $fichierLog
echo "*                           Fin du script                                *" | tee -a $fichierLog
echo "**************************************************************************" | tee -a $fichierLog
finish_time=$(date +%s)
difference=$(( finish_time-start_time ))
he=$(( difference/3600 ))
mi=$(( (( difference/60 ))-$(( he*60 )) ))
se=$(( difference-$(( $(( mi*60 ))+$(( he*3600 )) )) ))
echo "Durée d'execution : $he" heures "$mi" minutes "$se" secondes"" | tee -a $fichierLog


# Mesure espaceDisponibleDisqueUsbFinale
valeurBrute=`df -k $targetDir | grep % | awk '{print $4}'` # '$4' représente le 4ème élement de la ligne 'df -k'
espaceDisponibleDisqueUsbFinale=`echo $valeurBrute | awk '{print $1}'` # extraction 1er élement de la ligne (éventuellement titre)

# Conversion du retour de la commande 'df' suivant format : avec colonne des titres ou uniquement la valeur 
isdigit "$espaceDisponibleDisqueUsbFinale" # fonction
if [ "$?" != "0" ]; then
	espaceDisponibleDisqueUsbFinale=`echo $valeurBrute | awk '{print $2}'` # extraction 2ème élement de la ligne
fi


tailleTotalSauvegarde=`expr $espaceDisponibleDisqueUsb - $espaceDisponibleDisqueUsbFinale`

echo -n "Taille de la sauvegarde génerale                     : " | tee -a $fichierLog
afficherTaille $tailleTotalSauvegarde 2 # fonction

echo -n "Espace disponible sur disque USB après la sauvegarde : " | tee -a $fichierLog
afficherTaille $espaceDisponibleDisqueUsbFinale 2 # fonction


# Effacer le répertoire temporaire
rm -r -f "$ZONETMP" # Effacer le répertoire temporaire



#*******************************************************************************
# Sauvegarde des fichiers log et scripts sur le disque USB
#*******************************************************************************
echo " " | tee -a $fichierLog
echo " " | tee -a $fichierLog
echo " " | tee -a $fichierLog
echo -n "Copie fichiers log et scripts sur disque USB... " | tee -a $fichierLog


COPIEOK="true"

cp "$fichierLog"  "$targetDir/$backupDir/"
if [ "$?" -ne "0" ]; then # le '$?' == code sortie de la dernière commande'
	COPIEOK="false"
fi	

cp "SauvegardeGeneralePC.sh"  "$targetDir/$backupDir/"
if [ "$?" -ne "0" ]; then # le '$?' == code sortie de la dernière commande'
	COPIEOK="false"
fi	

cp "$scriptSousProgramme"  "$targetDir/$backupDir/"
if [ "$?" -ne "0" ]; then # le '$?' == code sortie de la dernière commande'
	COPIEOK="false"
fi	

if [ "$COPIEOK" == "true" ]; then
	echo "OK"
	echo " "
	echo " "
	echo " "
else
	echo "echec"
	echo " "
	echo "Interruption du script."
	echo "Réaliser la copie manuellement"
	echo " "
	echo " "
	echo " "
	setterm -cursor on # Demasquage du curseur
	exit 1
fi




setterm -cursor on # Demasquage du curseur
exit 0

